==> kubernetes-model-kustomize-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ReplacementFieldFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReplacementFieldFluentImpl<A extends ReplacementFieldFluent<A>> extends BaseFluent<A> implements ReplacementFieldFluent<A>{
  public ReplacementFieldFluentImpl() {
  }
  public ReplacementFieldFluentImpl(ReplacementField instance) {
    this.withPath(instance.getPath()); 
    this.withSource(instance.getSource()); 
    this.withTargets(instance.getTargets()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String path;
  private SourceSelectorBuilder source;
  private ArrayList<TargetSelectorBuilder> targets = new ArrayList<TargetSelectorBuilder>();
  private Map<String,Object> additionalProperties;
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceSelector getSource() {
    return this.source!=null ?this.source.build():null;
  }
  public SourceSelector buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  public A withSource(SourceSelector source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceSelectorBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public ReplacementFieldFluent.SourceNested<A> withNewSource() {
    return new ReplacementFieldFluentImpl.SourceNestedImpl();
  }
  public ReplacementFieldFluent.SourceNested<A> withNewSourceLike(SourceSelector item) {
    return new ReplacementFieldFluentImpl.SourceNestedImpl(item);
  }
  public ReplacementFieldFluent.SourceNested<A> editSource() {
    return withNewSourceLike(getSource());
  }
  public ReplacementFieldFluent.SourceNested<A> editOrNewSource() {
    return withNewSourceLike(getSource() != null ? getSource(): new SourceSelectorBuilder().build());
  }
  public ReplacementFieldFluent.SourceNested<A> editOrNewSourceLike(SourceSelector item) {
    return withNewSourceLike(getSource() != null ? getSource(): item);
  }
  public A addToTargets(Integer index,TargetSelector item) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").add(index >= 0 ? index : _visitables.get("targets").size(), builder);this.targets.add(index >= 0 ? index : targets.size(), builder); return (A)this;
  }
  public A setToTargets(Integer index,TargetSelector item) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    TargetSelectorBuilder builder = new TargetSelectorBuilder(item);
    if (index < 0 || index >= _visitables.get("targets").size()) { _visitables.get("targets").add(builder); } else { _visitables.get("targets").set(index, builder);}
    if (index < 0 || index >= targets.size()) { targets.add(builder); } else { targets.set(index, builder);}
     return (A)this;
  }
  public A addToTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").add(builder);this.targets.add(builder);} return (A)this;
  }
  public A addAllToTargets(Collection<TargetSelector> items) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").add(builder);this.targets.add(builder);} return (A)this;
  }
  public A removeFromTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items) {
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").remove(builder);if (this.targets != null) {this.targets.remove(builder);}} return (A)this;
  }
  public A removeAllFromTargets(Collection<TargetSelector> items) {
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").remove(builder);if (this.targets != null) {this.targets.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromTargets(Predicate<TargetSelectorBuilder> predicate) {
    if (targets == null) return (A) this;
    final Iterator<TargetSelectorBuilder> each = targets.iterator();
    final List visitables = _visitables.get("targets");
    while (each.hasNext()) {
      TargetSelectorBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TargetSelector> getTargets() {
    return targets != null ? build(targets) : null;
  }
  public List<TargetSelector> buildTargets() {
    return targets != null ? build(targets) : null;
  }
  public TargetSelector buildTarget(Integer index) {
    return this.targets.get(index).build();
  }
  public TargetSelector buildFirstTarget() {
    return this.targets.get(0).build();
  }
  public TargetSelector buildLastTarget() {
    return this.targets.get(targets.size() - 1).build();
  }
  public TargetSelector buildMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    for (TargetSelectorBuilder item: targets) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    for (TargetSelectorBuilder item: targets) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withTargets(List<TargetSelector> targets) {
    if (this.targets != null) { _visitables.get("targets").removeAll(this.targets);}
    if (targets != null) {this.targets = new ArrayList(); for (TargetSelector item : targets){this.addToTargets(item);}} else { this.targets = null;} return (A) this;
  }
  public A withTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... targets) {
    if (this.targets != null) {this.targets.clear();}
    if (targets != null) {for (TargetSelector item :targets){ this.addToTargets(item);}} return (A) this;
  }
  public Boolean hasTargets() {
    return targets != null && !targets.isEmpty();
  }
  public ReplacementFieldFluent.TargetsNested<A> addNewTarget() {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl();
  }
  public ReplacementFieldFluent.TargetsNested<A> addNewTargetLike(TargetSelector item) {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl(-1, item);
  }
  public ReplacementFieldFluent.TargetsNested<A> setNewTargetLike(Integer index,TargetSelector item) {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl(index, item);
  }
  public ReplacementFieldFluent.TargetsNested<A> editTarget(Integer index) {
    if (targets.size() <= index) throw new RuntimeException("Can't edit targets. Index exceeds size.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public ReplacementFieldFluent.TargetsNested<A> editFirstTarget() {
    if (targets.size() == 0) throw new RuntimeException("Can't edit first targets. The list is empty.");
    return setNewTargetLike(0, buildTarget(0));
  }
  public ReplacementFieldFluent.TargetsNested<A> editLastTarget() {
    int index = targets.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last targets. The list is empty.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public ReplacementFieldFluent.TargetsNested<A> editMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    int index = -1;
    for (int i=0;i<targets.size();i++) { 
    if (predicate.test(targets.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching targets. No match found.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReplacementFieldFluentImpl that = (ReplacementFieldFluentImpl) o;
    if (path != null ? !path.equals(that.path) :that.path != null) return false;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (targets != null ? !targets.equals(that.targets) :that.targets != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  source,  targets,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (targets != null && !targets.isEmpty()) { sb.append("targets:"); sb.append(targets + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class SourceNestedImpl<N> extends SourceSelectorFluentImpl<ReplacementFieldFluent.SourceNested<N>> implements ReplacementFieldFluent.SourceNested<N>,Nested<N>{
    SourceNestedImpl(SourceSelector item) {
      this.builder = new SourceSelectorBuilder(this, item);
    }
    SourceNestedImpl() {
      this.builder = new SourceSelectorBuilder(this);
    }
    SourceSelectorBuilder builder;
    public N and() {
      return (N) ReplacementFieldFluentImpl.this.withSource(builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  class TargetsNestedImpl<N> extends TargetSelectorFluentImpl<ReplacementFieldFluent.TargetsNested<N>> implements ReplacementFieldFluent.TargetsNested<N>,Nested<N>{
    TargetsNestedImpl(Integer index,TargetSelector item) {
      this.index = index;
      this.builder = new TargetSelectorBuilder(this, item);
    }
    TargetsNestedImpl() {
      this.index = -1;
      this.builder = new TargetSelectorBuilder(this);
    }
    TargetSelectorBuilder builder;
    Integer index;
    public N and() {
      return (N) ReplacementFieldFluentImpl.this.setToTargets(index,builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-kustomize-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/kustomize/v1beta1/ReplacementFieldFluentImpl.java <==
package io.fabric8.kubernetes.api.model.kustomize.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReplacementFieldFluentImpl<A extends ReplacementFieldFluent<A>> extends BaseFluent<A> implements ReplacementFieldFluent<A>{
  public ReplacementFieldFluentImpl() {
  }
  public ReplacementFieldFluentImpl(ReplacementField instance) {
    if (instance != null) {
      this.withPath(instance.getPath());
      this.withSource(instance.getSource());
      this.withTargets(instance.getTargets());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String path;
  private SourceSelectorBuilder source;
  private ArrayList<TargetSelectorBuilder> targets = new ArrayList<TargetSelectorBuilder>();
  private Map<String,Object> additionalProperties;
  public String getPath() {
    return this.path;
  }
  public A withPath(String path) {
    this.path=path; return (A) this;
  }
  public Boolean hasPath() {
    return this.path != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSource instead.
   * @return The buildable object.
   */
  @Deprecated
  public SourceSelector getSource() {
    return this.source!=null ?this.source.build():null;
  }
  public SourceSelector buildSource() {
    return this.source!=null ?this.source.build():null;
  }
  public A withSource(SourceSelector source) {
    _visitables.get("source").remove(this.source);
    if (source!=null){ this.source= new SourceSelectorBuilder(source); _visitables.get("source").add(this.source);} else { this.source = null; _visitables.get("source").remove(this.source); } return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public ReplacementFieldFluentImpl.SourceNested<A> withNewSource() {
    return new ReplacementFieldFluentImpl.SourceNestedImpl();
  }
  public ReplacementFieldFluentImpl.SourceNested<A> withNewSourceLike(SourceSelector item) {
    return new ReplacementFieldFluentImpl.SourceNestedImpl(item);
  }
  public ReplacementFieldFluentImpl.SourceNested<A> editSource() {
    return withNewSourceLike(getSource());
  }
  public ReplacementFieldFluentImpl.SourceNested<A> editOrNewSource() {
    return withNewSourceLike(getSource() != null ? getSource(): new SourceSelectorBuilder().build());
  }
  public ReplacementFieldFluentImpl.SourceNested<A> editOrNewSourceLike(SourceSelector item) {
    return withNewSourceLike(getSource() != null ? getSource(): item);
  }
  public A addToTargets(int index,TargetSelector item) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    TargetSelectorBuilder builder = new TargetSelectorBuilder(item);
    if (index < 0 || index >= targets.size()) { _visitables.get("targets").add(builder); targets.add(builder); } else { _visitables.get("targets").add(index, builder); targets.add(index, builder);}
    return (A)this;
  }
  public A setToTargets(int index,TargetSelector item) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    TargetSelectorBuilder builder = new TargetSelectorBuilder(item);
    if (index < 0 || index >= targets.size()) { _visitables.get("targets").add(builder); targets.add(builder); } else { _visitables.get("targets").set(index, builder); targets.set(index, builder);}
    return (A)this;
  }
  public A addToTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").add(builder);this.targets.add(builder);} return (A)this;
  }
  public A addAllToTargets(Collection<TargetSelector> items) {
    if (this.targets == null) {this.targets = new ArrayList<TargetSelectorBuilder>();}
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").add(builder);this.targets.add(builder);} return (A)this;
  }
  public A removeFromTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... items) {
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").remove(builder);if (this.targets != null) {this.targets.remove(builder);}} return (A)this;
  }
  public A removeAllFromTargets(Collection<TargetSelector> items) {
    for (TargetSelector item : items) {TargetSelectorBuilder builder = new TargetSelectorBuilder(item);_visitables.get("targets").remove(builder);if (this.targets != null) {this.targets.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromTargets(Predicate<TargetSelectorBuilder> predicate) {
    if (targets == null) return (A) this;
    final Iterator<TargetSelectorBuilder> each = targets.iterator();
    final List visitables = _visitables.get("targets");
    while (each.hasNext()) {
      TargetSelectorBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildTargets instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<TargetSelector> getTargets() {
    return targets != null ? build(targets) : null;
  }
  public List<TargetSelector> buildTargets() {
    return targets != null ? build(targets) : null;
  }
  public TargetSelector buildTarget(int index) {
    return this.targets.get(index).build();
  }
  public TargetSelector buildFirstTarget() {
    return this.targets.get(0).build();
  }
  public TargetSelector buildLastTarget() {
    return this.targets.get(targets.size() - 1).build();
  }
  public TargetSelector buildMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    for (TargetSelectorBuilder item: targets) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    for (TargetSelectorBuilder item: targets) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withTargets(List<TargetSelector> targets) {
    if (this.targets != null) { _visitables.get("targets").clear();}
    if (targets != null) {this.targets = new ArrayList(); for (TargetSelector item : targets){this.addToTargets(item);}} else { this.targets = null;} return (A) this;
  }
  public A withTargets(io.fabric8.kubernetes.api.model.kustomize.v1beta1.TargetSelector... targets) {
    if (this.targets != null) {this.targets.clear(); _visitables.remove("targets"); }
    if (targets != null) {for (TargetSelector item :targets){ this.addToTargets(item);}} return (A) this;
  }
  public Boolean hasTargets() {
    return targets != null && !targets.isEmpty();
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> addNewTarget() {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl();
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> addNewTargetLike(TargetSelector item) {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl(-1, item);
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> setNewTargetLike(int index,TargetSelector item) {
    return new ReplacementFieldFluentImpl.TargetsNestedImpl(index, item);
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> editTarget(int index) {
    if (targets.size() <= index) throw new RuntimeException("Can't edit targets. Index exceeds size.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> editFirstTarget() {
    if (targets.size() == 0) throw new RuntimeException("Can't edit first targets. The list is empty.");
    return setNewTargetLike(0, buildTarget(0));
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> editLastTarget() {
    int index = targets.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last targets. The list is empty.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public ReplacementFieldFluentImpl.TargetsNested<A> editMatchingTarget(Predicate<TargetSelectorBuilder> predicate) {
    int index = -1;
    for (int i=0;i<targets.size();i++) { 
    if (predicate.test(targets.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching targets. No match found.");
    return setNewTargetLike(index, buildTarget(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReplacementFieldFluentImpl that = (ReplacementFieldFluentImpl) o;
    if (!java.util.Objects.equals(path, that.path)) return false;

    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(targets, that.targets)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(path,  source,  targets,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (path != null) { sb.append("path:"); sb.append(path + ","); }
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (targets != null) { sb.append("targets:"); sb.append(targets + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class SourceNestedImpl<N> extends SourceSelectorFluentImpl<ReplacementFieldFluentImpl.SourceNested<N>> implements ReplacementFieldFluentImpl.SourceNested<N>,Nested<N>{
    SourceNestedImpl(SourceSelector item) {
      this.builder = new SourceSelectorBuilder(this, item);
    }
    SourceNestedImpl() {
      this.builder = new SourceSelectorBuilder(this);
    }
    SourceSelectorBuilder builder;
    public N and() {
      return (N) ReplacementFieldFluentImpl.this.withSource(builder.build());
    }
    public N endSource() {
      return and();
    }
    
  }
  class TargetsNestedImpl<N> extends TargetSelectorFluentImpl<ReplacementFieldFluentImpl.TargetsNested<N>> implements ReplacementFieldFluentImpl.TargetsNested<N>,Nested<N>{
    TargetsNestedImpl(int index,TargetSelector item) {
      this.index = index;
      this.builder = new TargetSelectorBuilder(this, item);
    }
    TargetsNestedImpl() {
      this.index = -1;
      this.builder = new TargetSelectorBuilder(this);
    }
    TargetSelectorBuilder builder;
    int index;
    public N and() {
      return (N) ReplacementFieldFluentImpl.this.setToTargets(index,builder.build());
    }
    public N endTarget() {
      return and();
    }
    
  }
  
}
